==> gammaray_2.9.0.orig.tar.gz: gammaray-2.9.0/core/tools/objectinspector/stacktraceextension.cpp <==
/*
  stacktraceextension.cpp

  This file is part of GammaRay, the Qt application inspection and
  manipulation tool.

  Copyright (C) 2017-2018 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
  Author: Volker Krause <volker.krause@kdab.com>

  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
  accordance with GammaRay Commercial License Agreement provided with the Software.

  Contact info@kdab.com if any conditions of this licensing are not clear to you.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "stacktraceextension.h"
#include "stacktracemodel.h"

#include <core/probe.h>
#include <core/propertycontroller.h>

#include <QDebug>

using namespace GammaRay;

StackTraceExtension::StackTraceExtension(PropertyController* controller)
    : PropertyControllerExtension(controller->objectBaseName() + ".stackTrace")
    , m_model(new StackTraceModel(controller))
{
    controller->registerModel(m_model, QStringLiteral("stackTraceModel"));
}

StackTraceExtension::~StackTraceExtension()
{
}

bool StackTraceExtension::setQObject(QObject *object)
{
    const auto trace = Probe::instance()->objectCreationStackTrace(object);
    m_model->setStackTrace(trace);
    return !trace.empty();
}

==> gammaray_2.11.0.orig.tar.gz: gammaray-2.11.0/core/tools/objectinspector/stacktraceextension.cpp <==
/*
  stacktraceextension.cpp

  This file is part of GammaRay, the Qt application inspection and
  manipulation tool.

  Copyright (C) 2017-2019 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
  Author: Volker Krause <volker.krause@kdab.com>

  Licensees holding valid commercial KDAB GammaRay licenses may use this file in
  accordance with GammaRay Commercial License Agreement provided with the Software.

  Contact info@kdab.com if any conditions of this licensing are not clear to you.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "stacktraceextension.h"
#include "stacktracemodel.h"

#include <core/probe.h>
#include <core/propertycontroller.h>

#include <QDebug>

using namespace GammaRay;

StackTraceExtension::StackTraceExtension(PropertyController* controller)
    : PropertyControllerExtension(controller->objectBaseName() + ".stackTrace")
    , m_model(new StackTraceModel(controller))
{
    controller->registerModel(m_model, QStringLiteral("stackTraceModel"));
}

StackTraceExtension::~StackTraceExtension() = default;

bool StackTraceExtension::setQObject(QObject *object)
{
    const auto trace = Probe::instance()->objectCreationStackTrace(object);
    m_model->setStackTrace(trace);
    return !trace.empty();
}
